@@ -28,12 +28,18 @@
 #include <QDir>
 #include <QMenu>
 #include <QContextMenuEvent>
-#include <QtWebEngineWidgets/QWebEngineSettings>
-#include <QtWebEngineWidgets/QWebEngineProfile>
-#include <QtWebEngineWidgets/QWebEnginePage>
-#include <QtWebEngineWidgets/QWebEngineView>
-#include <QtWebEngineWidgets/QWebEngineScript>
-#include <QtWebEngineWidgets/QWebEngineContextMenuData>
+#include <QtWebEngineWidgets>
+#include <QtWebEngineCore>
+#include <QWebEngineSettings>
+#include <QWebEngineProfile>
+#include <QWebEnginePage>
+#include <QWebEngineView>
+#include <QWebEngineScript>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QWebEngineContextMenuRequest>
+#else
+#include <QWebEngineContextMenuData>
+#endif
 #include <QDebug>
 
 #include "Utility.h"
@@ -43,6 +49,13 @@
 #include "WebPageEdit.h"
 #include "WebViewEdit.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+#endif
+
+
 #define DBG if(0)
 
 const QString SET_CURSOR_JS2 =
@@ -139,29 +152,45 @@ WebViewEdit::~WebViewEdit()
 
 void WebViewEdit::contextMenuEvent(QContextMenuEvent *event)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QWebEngineContextMenuData &data = page()->contextMenuData();
     Q_ASSERT(data.isValid());
+#else
+    const QWebEngineContextMenuRequest* request = lastContextMenuRequest();
+#endif
 
     QWebEngineProfile *profile = page()->profile();
     m_menu->clear();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (data.isContentEditable()) {
-
+#else
+    if (request->isContentEditable()) {
+#endif        
+        
         // Used for edit mode
         const QStringList &dictionaries = profile->spellCheckLanguages();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if (!data.misspelledWord().isEmpty()) {
+#else
+        if (!request->misspelledWord().isEmpty()) {
+#endif
             QFont boldFont = m_menu->font();
             boldFont.setBold(true);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             for (const QString &suggestion : data.spellCheckerSuggestions()) {
-	        QAction *action = m_menu->addAction(suggestion);
-	        action->setFont(boldFont);
+#else
+            for (const QString &suggestion : request->spellCheckerSuggestions()) {
+#endif
+	            QAction *action = m_menu->addAction(suggestion);
+	            action->setFont(boldFont);
 
-	        connect(action, &QAction::triggered, this, [=]() {
-	            page()->replaceMisspelledWord(suggestion);
-	          });
-             }
+	            connect(action, &QAction::triggered, this, [=]() {
+	                page()->replaceMisspelledWord(suggestion);
+	            });
+            }
 
             if (m_menu->actions().isEmpty()) {
 	        m_menu->addAction(tr("No suggestions"))->setEnabled(false);
@@ -172,7 +201,7 @@ void WebViewEdit::contextMenuEvent(QContextMenuEvent *event)
         m_menu->addAction(pageAction(QWebEnginePage::Cut));
         m_menu->addAction(pageAction(QWebEnginePage::Copy));
         m_menu->addAction(pageAction(QWebEnginePage::Paste));
-	m_menu->addAction(pageAction(QWebEnginePage::SelectAll));
+        m_menu->addAction(pageAction(QWebEnginePage::SelectAll));
 
         m_menu->addSeparator();
 
@@ -704,7 +733,7 @@ QList<ElementIndex> WebViewEdit::ConvertQWebPathToHierarchy(const QString & webp
 {
     // The location element hierarchy encoded in a string
     QString location_string = webpath;
-    QStringList elements    = location_string.split(",", QString::SkipEmptyParts);
+    QStringList elements    = location_string.split(",", QT_ENUM_SKIPEMPTYPARTS);
     QList<ElementIndex> location;
     foreach(QString element, elements) {
         ElementIndex new_element;
